tdub.features
-------------

A module for performing feature selection

.. currentmodule:: tdub.features

Class Summary
^^^^^^^^^^^^^

.. autosummary::

   FeatureSelector

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   create_parquet_files
   prepare_from_parquet

Reference
^^^^^^^^^

.. autoclass:: FeatureSelector
   :members:

.. autofunction:: create_parquet_files
.. autofunction:: prepare_from_parquet
